@@ -13,12 +13,15 @@
 #include <AppStreamQt/spdx.h>
 #include <AppStreamQt/version.h>
 #include <Category/Category.h>
+#include <KIconLoader>
 #include <KLocalizedString>
+#include <QCoroTimer>
 #include <QDebug>
 #include <QJsonArray>
 #include <QJsonObject>
 #include <QUrlQuery>
 
+using namespace std::chrono_literals;
 using namespace AppStreamUtils;
 
 QUrl AppStreamUtils::imageOfKind(const QList<AppStream::Image> &images, AppStream::Image::Kind kind)
@@ -35,20 +38,12 @@ QUrl AppStreamUtils::imageOfKind(const QList<AppStream::Image> &images, AppStrea
 
 QString AppStreamUtils::changelogToHtml(const AppStream::Component &appdata)
 {
-#if ASQ_CHECK_VERSION(1, 0, 0)
     const auto releases = appdata.releasesPlain();
-#else
-    const auto releases = appdata.releases();
-#endif
     if (releases.isEmpty()) {
         return {};
     }
 
-#if ASQ_CHECK_VERSION(1, 0, 0)
     const auto release = releases.indexSafe(0).value();
-#else
-    const auto release = releases.constFirst();
-#endif
     if (release.description().isEmpty())
         return {};
 
@@ -90,37 +85,43 @@ QJsonArray AppStreamUtils::licenses(const QString &spdx)
     for (const auto &token : licenses) {
         if (token.size() == 1 && tokens.contains(token.at(0)))
             continue;
-        ret += license(token.mid(1)); // tokenize prefixes with an @ for some reason
+
+        // Sometimes tokenize prefixes with an @ for some reason
+        if (token.startsWith(QStringLiteral("@"))) {
+            ret += license(token.mid(1));
+        } else {
+            ret += license(token);
+        }
     }
     return ret;
 }
 
 QJsonObject AppStreamUtils::license(const QString &license)
 {
-    bool publicLicense = false;
     QString name = license;
-    if (license.startsWith(QLatin1String("LicenseRef-proprietary"))) {
+    QString url = QString();
+    QString licenseType = QStringLiteral("unknown");
+
+    if (license.isEmpty() || license.compare(QStringLiteral("unknown"), Qt::CaseInsensitive) == 0) {
+        name = i18n("Unknown");
+    } else if (license.startsWith(QLatin1String("LicenseRef-proprietary"), Qt::CaseInsensitive)) {
         name = i18n("Proprietary");
-    } else if (license == QLatin1String("LicenseRef-public-domain")) {
+        licenseType = QStringLiteral("proprietary");
+    } else if (license.startsWith(QLatin1String("LicenseRef-public-domain"), Qt::CaseInsensitive)
+               || license.contains(QLatin1String("public domain"), Qt::CaseInsensitive)) {
         name = i18n("Public Domain");
-        publicLicense = true;
+        licenseType = QStringLiteral("free");
+    } else if (!AppStream::SPDX::isLicenseId(license)) {
+        licenseType = QStringLiteral("non-free");
+    } else {
+        url = AppStream::SPDX::licenseUrl(license);
+        licenseType = AppStream::SPDX::isFreeLicense(license) ? QStringLiteral("free") : QStringLiteral("non-free");
     }
 
-    if (license.isEmpty()) {
-        return {
-            {QStringLiteral("name"), i18n("Unknown")},
-            {QStringLiteral("hasFreedom"), true}, // give it the benefit of the doubt
-        };
-    }
-    if (!AppStream::SPDX::isLicenseId(license))
-        return {
-            {QStringLiteral("name"), name},
-            {QStringLiteral("hasFreedom"), true}, // give it the benefit of the doubt
-        };
     return {
-        {QStringLiteral("name"), name},
-        {QStringLiteral("url"), {AppStream::SPDX::licenseUrl(license)}},
-        {QStringLiteral("hasFreedom"), AppStream::SPDX::isFreeLicense(license) || publicLicense},
+        {QLatin1StringView("name"), name},
+        {QLatin1StringView("url"), {url}},
+        {QLatin1StringView("licenseType"), licenseType},
     };
 }
 
@@ -151,7 +152,6 @@ QString AppStreamUtils::versionString(const QString &version, const AppStream::C
 
 QString AppStreamUtils::contentRatingDescription(const AppStream::Component &appdata)
 {
-#if ASQ_CHECK_VERSION(0, 15, 6)
     const auto ratings = appdata.contentRatings();
     QString ret;
     for (const auto &r : ratings) {
@@ -164,83 +164,16 @@ QString AppStreamUtils::contentRatingDescription(const AppStream::Component &app
     }
 
     return ret;
-#else
-    Q_UNUSED(appdata);
-    return {};
-#endif
-}
-
-QString AppStreamUtils::contentRatingText(const AppStream::Component &appdata)
-{
-#if ASQ_CHECK_VERSION(0, 15, 6)
-    const auto ratings = appdata.contentRatings();
-    AppStream::ContentRating::RatingValue intensity = AppStream::ContentRating::RatingValueUnknown;
-    for (const auto &r : ratings) {
-        const auto ratingIds = r.ratingIds();
-        for (const auto &id : ratingIds) {
-            intensity = std::max(r.value(id), intensity);
-        }
-    }
-
-    static QStringList texts = {
-        {},
-        i18nc("Open Age Ratings Service (https://hughsie.github.io/oars) description of content suitable for everyone", "All Audiences"),
-        i18nc("Open Age Ratings Service (https://hughsie.github.io/oars) description of content with relatively benign themes only unsuitable for very young "
-              "children, such as minor cartoon violence or mild profanity",
-              "Mild Content"),
-        i18nc("Open Age Ratings Service (https://hughsie.github.io/oars) description of content with some intense themes, such as somewhat realistic "
-              "violence, references to sexuality, or adult profanity",
-              "Moderate Content"),
-        i18nc("Open Age Ratings Service (https://hughsie.github.io/oars) description of mature content that could be quite objectionable or unsuitable for "
-              "young audiences, such as realistic graphic violence, extreme profanity or nudity, or glorification of drug use",
-              "Intense Content"),
-    };
-    return texts[intensity];
-#else
-    Q_UNUSED(appdata);
-    return {};
-#endif
-}
-
-AbstractResource::ContentIntensity AppStreamUtils::contentRatingIntensity(const AppStream::Component &appdata)
-{
-#if ASQ_CHECK_VERSION(0, 15, 6)
-    const auto ratings = appdata.contentRatings();
-    AppStream::ContentRating::RatingValue intensity = AppStream::ContentRating::RatingValueUnknown;
-    for (const auto &r : ratings) {
-        const auto ratingIds = r.ratingIds();
-        for (const auto &id : ratingIds) {
-            intensity = std::max(r.value(id), intensity);
-        }
-    }
-
-    static QVector<AbstractResource::ContentIntensity> intensities = {
-        AbstractResource::Mild,
-        AbstractResource::Mild,
-        AbstractResource::Mild,
-        AbstractResource::Intense,
-        AbstractResource::Intense,
-    };
-    return intensities[intensity];
-#else
-    Q_UNUSED(appdata);
-    return {};
-#endif
 }
 
 uint AppStreamUtils::contentRatingMinimumAge(const AppStream::Component &appdata)
 {
-#if ASQ_CHECK_VERSION(0, 15, 6)
     const auto ratings = appdata.contentRatings();
     uint minimumAge = 0;
     for (const auto &r : ratings) {
         minimumAge = std::max(r.minimumAge(), minimumAge);
     }
     return minimumAge;
-#else
-    Q_UNUSED(appdata);
-    return 0;
-#endif
 }
 
 static void kRemoveDuplicates(AppStream::ComponentBox &input, AppStream::Bundle::Kind kind)
@@ -257,12 +190,32 @@ static void kRemoveDuplicates(AppStream::ComponentBox &input, AppStream::Bundle:
     }
 }
 
-AppStream::ComponentBox AppStreamUtils::componentsByCategories(AppStream::Pool *pool, Category *cat, AppStream::Bundle::Kind kind)
+QCoro::Task<AppStream::ComponentBox> AppStreamUtils::componentsByCategoriesTask(AppStream::Pool *pool, Category *cat, AppStream::Bundle::Kind kind)
 {
+    if (cat->name() == QLatin1StringView("All Applications")) {
+        co_return pool->componentsByKind(AppStream::Component::KindDesktopApp);
+    }
+
     AppStream::ComponentBox ret(AppStream::ComponentBox::FlagNoChecks);
     for (const auto &categoryName : cat->involvedCategories()) {
+        // Give the eventloop some breathing room by suspending execution for a bit. This in particular should keep the
+        // UI more responsive while we fetch a substantial amount of components on e.g. the all apps view.
+        constexpr auto arbitrarySuspendTime = 64ms;
+        QTimer timer;
+        timer.start(arbitrarySuspendTime);
+        co_await timer;
+
         ret += pool->componentsByCategories({categoryName});
     }
     kRemoveDuplicates(ret, kind);
-    return ret;
+    co_return ret;
+}
+
+DISCOVERCOMMON_EXPORT bool AppStreamUtils::kIconLoaderHasIcon(const QString &name)
+{
+    static auto icons = [] {
+        auto icons = KIconLoader::global()->queryIcons(-1);
+        return QSet<QString>(icons.cbegin(), icons.cend());
+    }();
+    return icons.contains(name);
 }
