@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef FLATPAKPERMISSION_H
-#define FLATPAKPERMISSION_H
+#pragma once
 
 #include <QAbstractListModel>
 #include <QString>
@@ -21,9 +20,9 @@ public:
     QString description() const;
 
 private:
-    const QString m_brief;
-    const QString m_description;
-    const QString m_icon;
+    QString m_brief;
+    QString m_description;
+    QString m_icon;
 };
 
 class FlatpakPermissionsModel : public QAbstractListModel
@@ -40,10 +39,8 @@ public:
 
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     QVariant data(const QModelIndex &index, int role) const override;
-    virtual QHash<int, QByteArray> roleNames() const override;
+    QHash<int, QByteArray> roleNames() const override;
 
 private:
     QVector<FlatpakPermission> m_permissions;
 };
-
-#endif // FLATPAKPERMISSION_H
